==> phplist-2.10.3.tgz: lists/admin/lan/es/message.php <==
<?php
$lan = array(
 'Please select a message to display' => 'Escoja el mensaje que hay
 que mostrar',
 'Attachments for this message' => 'Ficheros adjuntos para este mensaje',
 'No attachments' => 'No hay adjuntos',
 'Filename' => 'Nombre del fichero',
 'Size' => 'Tama&ntilde;o',
 'Mime Type' => 'Tipo MIME',
 'Description' => 'Descripci&oacute;n',
 'Lists this message has been sent to' => 'Listas a las que se ha
 enviado este mensaje',
 'None yet' => 'Todav&iacute;a a ninguna',
 'Send this (same) message to (a) new list(s)' => 'Enviar este (mismo)
 mensaje a otra(s) lista(s)',
 'List is Active' => 'La lista est&aacute; activa',
 'List is not Active' => 'La lista no est&aacute; activa',
 '<b>Note:</b> this message has already been sent to all lists. To
 resend it to new users use the "Requeue" function.' => '<b>Nota:</b>
 este mensaje ya se ha enviado a todas las listas. Para enviarlo a
 usuarios nuevos utilice la funci&oacute;n &#171;Volver a poner en cola&#187;.',
 'Resend' => 'Reenviar',
 'id' => 'id',
 'subject' => 'asunto',
 'fromfield' => 'campo &#171;de&#187;',
 'tofield' => 'campo &#171;a&#187;',
 'replyto' => 'responder a',
 'message' => 'mensaje',
 'textmessage' => 'mensaje de texto',
 'footer' => 'pie de mensaje',
 'entered' => 'creado',
 'modified' => 'modificado',
 'embargo' => 'embargo',
 'repeatinterval' => 'repetir intervalo',
 'repeatuntil' => 'repetir hasta que',
 'status' => 'estado',
 'userselection' => 'selecci&oacute;n de usuario',
 'sent' => 'enviado',
 'htmlformatted' => 'formato HTML',
 'sendformat' => 'formato de env&iacute;o',
 'template' => 'patr&oacute;n',
 'processed' => 'procesado',
 'astext' => 'como texto plano',
 'ashtml' => 'como HTML',
 'astextandhtml' => 'como texto plano y HTML',
 'aspdf' => 'como PDF',
 'astextandpdf' => 'como texto plano y PDF',
 'viewed' => 'visto',
 'bouncecount' => 'n&uacute;mero de rebotes',
 'sendstart' => 'comenzar env&iacute;o',
 'rsstemplate' => 'patr&oacute;n RSS',
 'owner' => 'due&ntilde;o',
);
?>

==> phplist-2.10.14p1.tgz: lists/admin/lan/es/message.php <==
<?php
$lan = array(
 'Please select a message to display' => 'Escoja el mensaje que hay
 que mostrar',
 'Attachments for this message' => 'Ficheros adjuntos para este mensaje',
 'No attachments' => 'No hay adjuntos',
 'Filename' => 'Nombre del fichero',
 'Size' => 'Tama&ntilde;o',
 'Mime Type' => 'Tipo MIME',
 'Description' => 'Descripci&oacute;n',
 'Lists this message has been sent to' => 'Listas a las que se ha
 enviado este mensaje',
 'None yet' => 'Todav&iacute;a a ninguna',
 'Send this (same) message to (a) new list(s)' => 'Enviar este (mismo)
 mensaje a otra(s) lista(s)',
 'List is Active' => 'La lista est&aacute; activa',
 'List is not Active' => 'La lista no est&aacute; activa',
 '<b>Note:</b> this message has already been sent to all lists. To
 resend it to new users use the "Requeue" function.' => '<b>Nota:</b>
 este mensaje ya se ha enviado a todas las listas. Para enviarlo a
 usuarios nuevos utilice la funci&oacute;n &#171;Volver a poner en cola&#187;.',
 'Resend' => 'Reenviar',
 'id' => 'id',
 'subject' => 'asunto',
 'fromfield' => 'campo &#171;de&#187;',
 'tofield' => 'campo &#171;a&#187;',
 'replyto' => 'responder a',
 'message' => 'mensaje',
 'textmessage' => 'mensaje de texto',
 'footer' => 'pie de mensaje',
 'entered' => 'creado',
 'modified' => 'modificado',
 'embargo' => 'embargo',
 'repeatinterval' => 'repetir intervalo',
 'repeatuntil' => 'repetir hasta que',
 'status' => 'estado',
 'userselection' => 'selecci&oacute;n de usuario',
 'sent' => 'enviado',
 'htmlformatted' => 'formato HTML',
 'sendformat' => 'formato de env&iacute;o',
 'template' => 'plantilla',
 'processed' => 'procesado',
 'astext' => 'como texto plano',
 'ashtml' => 'como HTML',
// 'astextandhtml' => 'como texto plano y HTML', //obsolete by bug 0009687
 'aspdf' => 'como PDF',
 'astextandpdf' => 'como texto plano y PDF',
 'viewed' => 'visto',
 'bouncecount' => 'n&uacute;mero de rebotes',
 'sendstart' => 'comenzar env&iacute;o',
 'rsstemplate' => 'plantilla RSS',
 'owner' => 'due&ntilde;o',
);
?>
